package com.yijia.customer.mapper;

import java.util.List;

import com.yijia.customer.domain.CustomerManage;


/**
 * 客户管理Mapper接口
 * 
 * @author yijia
 * @date 2020-12-21
 */
public interface CustomerManageMapper 
{
    /**
     * 查询客户管理
     * 
     * @param id 客户管理ID
     * @return 客户管理
     */
    public CustomerManage selectCustomerManageById(Long id);

    /**
     * 查询客户管理列表
     * 
     * @param customerManage 客户管理
     * @return 客户管理集合
     */
    public List<CustomerManage> selectCustomerManageList(CustomerManage customerManage);

    /**
     * 新增客户管理
     * 
     * @param customerManage 客户管理
     * @return 结果
     */
    public int insertCustomerManage(CustomerManage customerManage);

    /**
     * 修改客户管理
     * 
     * @param customerManage 客户管理
     * @return 结果
     */
    public int updateCustomerManage(CustomerManage customerManage);

    /**
     * 删除客户管理
     * 
     * @param id 客户管理ID
     * @return 结果
     */
    public int deleteCustomerManageById(Long id);

    /**
     * 批量删除客户管理
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteCustomerManageByIds(Long[] ids);
}
